@@ -6,7 +6,7 @@ utils::globalVariables(c("ni", "fi", "sumatorio", "variable2",
                          "media.muestral","incluido","value",
                          "grupo","grupo2","vx","vy","coeficiente.determinacion",
                          "varianza.regresion","valores.teoricos","errores",
-                         "obs","sc.observados","sc.teoricos","errores2","suma.cuadrados.total",
+                         "obs","id","sc.observados","sc.teoricos","errores2","suma.cuadrados.total",
                          "suma.cuadrados.errores","suma.cuadrados.regresion","varianza.residual",
                          "varianza.residuos", "leverage", "puntos.palanca","error.norm",
                          "X","momento", "atipico", "lm", "mediamovil", "paso1_ive",
